==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/fi.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalenteri",
    "%s has published the calendar \"%s\"" : "%s julkaisi kalenterin \"%s\"",
    "Too many redirects. Aborting ..." : "Liian monta uudelleenohjausta. Keskeytetään ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Etäpalvelin ei antanut pääsyä kalenteriin (HTTP-virhe {%s})",
    "Error connecting to remote server" : "Virhe yhdistettäessä etäpalvelimeen",
    "Individual" : "Yksittäinen",
    "Group" : "Ryhmä",
    "Resource" : "Resurssi",
    "Room" : "Huone",
    "Unknown" : "Tuntematon",
    "Required" : "Vaadittu",
    "Optional" : "Valinnainen",
    "Does not attend" : "Ei osallistu",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Olet tuntemattomalla aikavyöhykkeellä ({tz}), palataan UTC-tilaan",
    "Please create a calendar first." : "Luo ensin kalenteri.",
    "New event" : "Uusi tapahtuma",
    "CalDAV address for clients" : "CalDAV-osoite asiakasohjelmille",
    "Error saving WebCal-calendar" : "Virhe tallentaessa WebCal-kalenteria",
    "WebDAV address for subscriptions" : "WebDAV-osoite tilauksille",
    "EMail has been sent." : "Sähköposti lähetetty.",
    "There was an issue while sending your EMail." : "Virhe lähetettäessä sähköpostia.",
    "group" : "ryhmä",
    "Details" : "Tiedot",
    "Attendees" : "Osallistujat",
    "Reminders" : "Muistutukset",
    "Repeating" : "Toisto",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
    "Confirmed" : "Vahvistettu",
    "Tentative" : "Alustava",
    "Cancelled" : "Peruttu",
    "Please add a title!" : "Lisää otsikko!",
    "Please select a calendar!" : "Valitse kalenteri!",
    "Global" : "Julkinen",
    "None" : "Ei mitään",
    "Every day" : "Päivittäin",
    "Every week" : "Viikottain",
    "Every month" : "Kuukausittain",
    "Every year" : "Vuosittain",
    "never" : "ei koskaan",
    "after" : "jälkeen",
    "How about getting started by importing some calendars?" : "Haluaisitko tuoda kalentereita?",
    "At time of event" : "Tapahtuman aikaan",
    "5 minutes before" : "5 minuuttia ennen",
    "10 minutes before" : "10 minuuttia ennen",
    "15 minutes before" : "15 minuuttia ennen",
    "30 minutes before" : "30 minuuttia ennen",
    "1 hour before" : "1 tunti ennen",
    "2 hours before" : "2 tuntia ennen",
    "Custom" : "Omavalintainen",
    "Audio" : "Ääni",
    "E Mail" : "Sähköposti",
    "Pop up" : "Ponnahdus",
    "sec" : "s",
    "min" : "min",
    "hours" : "tuntia",
    "days" : "päivää",
    "week" : "viikko",
    "before" : "ennen",
    "start" : "alku",
    "end" : "loppu",
    "Editing reminders of unknown type not supported." : "Tuntemattoman tyyppisten muistutusten muokkaamista ei tueta.",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Successfully imported" : "Tuotu onnistuneesti",
    "Partially imported, 1 failure" : "Tuotu osittain, 1 epäonnistui",
    "Partially imported, {n} failures" : "Tuotu osittain, {n} epäonnistui",
    "Audio alarm" : "Äänihälytys",
    "Pop-up" : "Ponnahdusikkuna",
    "E-Mail" : "Sähköposti",
    "{type} {time} before the event starts" : "{type} {time} ennen tapahtuman alkua",
    "{type} {time} before the event ends" : "{type} {time} ennen tapahtuman loppua",
    "{type} {time} after the event starts" : "{type} {time} tapahtuman alkamisen jälkeen",
    "{type} {time} after the event ends" : "{type} {time} tapahtuman päättymisen jälkeen",
    "{type} at the event's start" : "{type} tapahtuman alkaessa",
    "{type} at the event's end" : "{type} tapahtuman päättyessä",
    "{type} at {time}" : "{type} ajankohtana {time}",
    "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
    "Please enter a valid WebCal-URL" : "Anna kelvollinen WebCal-osoite",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kriittinen virhe webcal-välityspalvelimessa. Ota yhteyttä ylläpitäjään saadaksesi lisää tietoa.",
    "Title of the Event" : "Tapahtuman otsikko",
    "starts" : "alkaa",
    "ends" : "päättyy",
    "All day Event" : "Koko päivän tapahtuma",
    "Delete" : "Poista",
    "Cancel" : "Peruuta",
    "More ..." : "Lisää...",
    "Create" : "Luo",
    "Update" : "Päivitä",
    "Close" : "Sulje",
    "Location" : "Sijainti",
    "Description" : "Kuvaus",
    "Event status" : "Tapahtuman tila",
    "Visibility when sharing" : "Näkyvyys jaettaessa",
    "Export" : "Vie",
    "%s has published the calendar %s" : "%s julkaisi kalenterin %s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikkaa tästä päästäksesi siihen käsiksi",
    "Cheers!" : "Kiitos!",
    "We wanted to inform you that %s has published the calendar %s." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin %s.",
    "Click on the link below to access it" : "Klikkaa alla olevaa linkkiä päästäksesi siihen käsiksi",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "Today" : "Tänään",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
    "Share Calendar" : "Jaa kalenteri",
    "Shared" : "Jaettu",
    "More" : "Lisää",
    "Edit" : "Muokkaa",
    "Link" : "Linkki",
    "iCal link" : "iCal-linkki",
    "Download" : "Lataa",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "can edit" : "voi muokata",
    "Share link" : "Jaa linkki",
    "Public access" : "Avoin pääsy",
    "Email link to person" : "Lähetä linkki sähköpostitse",
    "Send" : "Lähetä",
    "New Calendar" : "Uusi kalenteri",
    "Name" : "Nimi",
    "New Subscription" : "Uusi tilaus",
    "Go back" : "Takaisin",
    "Go forward" : "Eteenpäin",
    "Edit event" : "Muokkaa tapahtumaa",
    "Delete Event" : "Poista tapahtuma",
    "Save Event" : "Tallenna tapahtuma",
    "Time" : "Aika",
    "Type" : "Tyyppi",
    "Relative" : "Suhteellinen",
    "Absolute" : "Absoluuttinen",
    "Repeat" : "Kertaa",
    "times every" : "kertaa joka",
    "Add" : "Lisää",
    "E-Mail address of attendee" : "Osallistujan sähköpostiosoite",
    "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
    "from" : "alkaen",
    "to" : "päättyen",
    "This event's repeating rule is not supported yet." : "Tämän tapahtuman toistuva sääntö ei ole vielä tuettu.",
    "Support for advanced rules will be added with subsequent updates." : "Tuki kehittyneille säännöille lisätään myöhemmin julkaistavissa päivityksissä.",
    "Reset repeating rule" : "Nollaa toistuva sääntö",
    "Repeat every ..." : "Toista joka ...",
    "end repeat ..." : "lopeta toisto ...",
    "times" : "kertaa",
    "Import Calendars" : "Tuo kalentereita",
    "Import canceled" : "Tuonti peruttu",
    "Analyzing calendar" : "Analysoidaan kalenteria",
    "The file contains objects incompatible with the selected calendar" : "Tiedosto sisältää valitun kalenterin kanssa yhteensopimattomia objekteja",
    "New calendar" : "Uusi kalenteri",
    "File is empty" : "Tiedosto on tyhjä",
    "Import scheduled" : "Tuonti ajastettu",
    "Subscribe & embed" : "Tilaa ja sisällytä",
    "Publish URL" : "Julkaise URL",
    "Settings & import" : "Asetukset ja tuonti",
    "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
    "Show week numbers" : "Näytä viikkonumerot",
    "Import calendar" : "Tuo kalenteri",
    "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
    "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV -osoite"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/fi.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalenteri",
    "%s has published the calendar \"%s\"" : "%s julkaisi kalenterin \"%s\"",
    "Too many redirects. Aborting ..." : "Liian monta uudelleenohjausta. Keskeytetään ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Etäpalvelin ei antanut pääsyä kalenteriin (HTTP-virhe {%s})",
    "Error connecting to remote server" : "Virhe yhdistettäessä etäpalvelimeen",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Virhe etäpalvelimen resurssia pyydettäessä. Sertifikaatti saattaa olla yhteensopimaton",
    "Error requesting resource on remote server" : "Virhe etäpalvelimen resurssia pyytäessä",
    "Individual" : "Yksittäinen",
    "Group" : "Ryhmä",
    "Resource" : "Resurssi",
    "Room" : "Huone",
    "Unknown" : "Tuntematon",
    "Required" : "Vaadittu",
    "Optional" : "Valinnainen",
    "Does not attend" : "Ei osallistu",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Olet tuntemattomalla aikavyöhykkeellä ({tz}), palataan UTC-tilaan",
    "Please create a calendar first." : "Luo ensin kalenteri.",
    "New event" : "Uusi tapahtuma",
    "CalDAV address for clients" : "CalDAV-osoite asiakasohjelmille",
    "Error saving WebCal-calendar" : "Virhe tallentaessa WebCal-kalenteria",
    "WebDAV address for subscriptions" : "WebDAV-osoite tilauksille",
    "EMail has been sent." : "Sähköposti lähetetty.",
    "There was an issue while sending your EMail." : "Virhe lähetettäessä sähköpostia.",
    "group" : "ryhmä",
    "Details" : "Tiedot",
    "Attendees" : "Osallistujat",
    "Reminders" : "Muistutukset",
    "Repeating" : "Toisto",
    "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
    "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
    "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
    "Confirmed" : "Vahvistettu",
    "Tentative" : "Alustava",
    "Cancelled" : "Peruttu",
    "Please add a title!" : "Lisää otsikko!",
    "Please select a calendar!" : "Valitse kalenteri!",
    "The event ends before it starts!" : "Tapahtuman päättymisajankohta on ennen alkamisajankohtaa!",
    "Global" : "Julkinen",
    "None" : "Ei mitään",
    "Every day" : "Päivittäin",
    "Every week" : "Viikottain",
    "Every month" : "Kuukausittain",
    "Every year" : "Vuosittain",
    "never" : "ei koskaan",
    "after" : "jälkeen",
    "How about getting started by importing some calendars?" : "Haluaisitko tuoda kalentereita?",
    "At time of event" : "Tapahtuman aikaan",
    "5 minutes before" : "5 minuuttia ennen",
    "10 minutes before" : "10 minuuttia ennen",
    "15 minutes before" : "15 minuuttia ennen",
    "30 minutes before" : "30 minuuttia ennen",
    "1 hour before" : "1 tunti ennen",
    "2 hours before" : "2 tuntia ennen",
    "Custom" : "Omavalintainen",
    "Audio" : "Ääni",
    "E Mail" : "Sähköposti",
    "Pop up" : "Ponnahdus",
    "sec" : "s",
    "min" : "min",
    "hours" : "tuntia",
    "days" : "päivää",
    "week" : "viikko",
    "before" : "ennen",
    "start" : "alku",
    "end" : "loppu",
    "Editing reminders of unknown type not supported." : "Tuntemattoman tyyppisten muistutusten muokkaamista ei tueta.",
    "Week {number} of {year}" : "Viikko {number} vuonna {year}",
    "Successfully imported" : "Tuotu onnistuneesti",
    "Partially imported, 1 failure" : "Tuotu osittain, 1 epäonnistui",
    "Partially imported, {n} failures" : "Tuotu osittain, {n} epäonnistui",
    "Audio alarm" : "Äänihälytys",
    "Pop-up" : "Ponnahdusikkuna",
    "E-Mail" : "Sähköposti",
    "{type} {time} before the event starts" : "{type} {time} ennen tapahtuman alkua",
    "{type} {time} before the event ends" : "{type} {time} ennen tapahtuman loppua",
    "{type} {time} after the event starts" : "{type} {time} tapahtuman alkamisen jälkeen",
    "{type} {time} after the event ends" : "{type} {time} tapahtuman päättymisen jälkeen",
    "{type} at the event's start" : "{type} tapahtuman alkaessa",
    "{type} at the event's end" : "{type} tapahtuman päättyessä",
    "{type} at {time}" : "{type} ajankohtana {time}",
    "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
    "Please enter a valid WebCal-URL" : "Anna kelvollinen WebCal-osoite",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kriittinen virhe webcal-välityspalvelimessa. Ota yhteyttä ylläpitäjään saadaksesi lisää tietoa.",
    "Title of the Event" : "Tapahtuman otsikko",
    "Starts" : "Alkaa",
    "Ends" : "Päättyy",
    "All day Event" : "Koko päivän tapahtuma",
    "Delete" : "Poista",
    "Cancel" : "Peruuta",
    "More ..." : "Lisää...",
    "Create" : "Luo",
    "Update" : "Päivitä",
    "Close" : "Sulje",
    "Location" : "Sijainti",
    "Description" : "Kuvaus",
    "Event status" : "Tapahtuman tila",
    "Visibility when sharing" : "Näkyvyys jaettaessa",
    "Export" : "Vie",
    "%s has published the calendar %s" : "%s julkaisi kalenterin %s",
    "Hello," : "Hei,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin {boldstart}%s{boldend}.",
    "Click here to access it" : "Klikkaa tästä päästäksesi siihen käsiksi",
    "Cheers!" : "Kiitos!",
    "We wanted to inform you that %s has published the calendar %s." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin %s.",
    "Click on the link below to access it" : "Klikkaa alla olevaa linkkiä päästäksesi siihen käsiksi",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
    "Day" : "Päivä",
    "Week" : "Viikko",
    "Month" : "Kuukausi",
    "Today" : "Tänään",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
    "Share Calendar" : "Jaa kalenteri",
    "Shared" : "Jaettu",
    "More" : "Lisää",
    "Edit" : "Muokkaa",
    "Link" : "Linkki",
    "iCal link" : "iCal-linkki",
    "Download" : "Lataa",
    "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
    "can edit" : "voi muokata",
    "Share link" : "Jaa linkki",
    "Public access" : "Avoin pääsy",
    "Email link to person" : "Lähetä linkki sähköpostitse",
    "Send" : "Lähetä",
    "New Calendar" : "Uusi kalenteri",
    "Name" : "Nimi",
    "New Subscription" : "Uusi tilaus",
    "Go back" : "Takaisin",
    "Go forward" : "Eteenpäin",
    "Calendar does not exist" : "Kalenteria ei ole olemassa",
    "Maybe you got a wrong link or the calendar was unshared?" : "Saatoit saada väärän linkin tai kalenteria ei ole jaettu?",
    "Edit event" : "Muokkaa tapahtumaa",
    "Delete Event" : "Poista tapahtuma",
    "Save Event" : "Tallenna tapahtuma",
    "Time" : "Aika",
    "Type" : "Tyyppi",
    "Relative" : "Suhteellinen",
    "Absolute" : "Absoluuttinen",
    "Repeat" : "Kertaa",
    "times every" : "kertaa joka",
    "Add" : "Lisää",
    "E-Mail address of attendee" : "Osallistujan sähköpostiosoite",
    "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
    "from" : "alkaen",
    "to" : "päättyen",
    "This event's repeating rule is not supported yet." : "Tämän tapahtuman toistuva sääntö ei ole vielä tuettu.",
    "Support for advanced rules will be added with subsequent updates." : "Tuki kehittyneille säännöille lisätään myöhemmin julkaistavissa päivityksissä.",
    "Reset repeating rule" : "Nollaa toistuva sääntö",
    "Repeat every ..." : "Toista joka ...",
    "end repeat ..." : "lopeta toisto ...",
    "times" : "kertaa",
    "Import Calendars" : "Tuo kalentereita",
    "Import canceled" : "Tuonti peruttu",
    "Analyzing calendar" : "Analysoidaan kalenteria",
    "The file contains objects incompatible with the selected calendar" : "Tiedosto sisältää valitun kalenterin kanssa yhteensopimattomia objekteja",
    "New calendar" : "Uusi kalenteri",
    "File is empty" : "Tiedosto on tyhjä",
    "Import scheduled" : "Tuonti ajastettu",
    "%s shared the calendar <strong>%s</strong> with you" : "%s jakoi kalenterin<strong>%s</strong>sinulle",
    "Embed" : "Upota",
    "IFrame to integrate" : "IFrame integraatio",
    "Publish URL" : "Julkaise URL",
    "Settings & import" : "Asetukset ja tuonti",
    "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
    "Show week numbers" : "Näytä viikkonumerot",
    "Import calendar" : "Tuo kalenteri",
    "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
    "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV -osoite",
    "Subscribe" : "Tilaa"
},
"nplurals=2; plural=(n != 1);");
